@@ -17,6 +17,7 @@
 
 import logging
 
+from novaclient import api_versions
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
@@ -55,20 +56,25 @@ class CreateServerGroup(command.ShowOne):
         parser.add_argument(
             '--policy',
             metavar='<policy>',
-            choices=['affinity', 'anti-affinity'],
             default='affinity',
             help=_("Add a policy to <name> "
                    "('affinity' or 'anti-affinity', "
-                   "default to 'affinity')")
+                   "defaults to 'affinity'). Specify --os-compute-api-version "
+                   "2.15 or higher for the 'soft-affinity' or "
+                   "'soft-anti-affinity' policy.")
         )
         return parser
 
     def take_action(self, parsed_args):
         compute_client = self.app.client_manager.compute
         info = {}
+
+        policy_arg = {'policies': [parsed_args.policy]}
+        if compute_client.api_version >= api_versions.APIVersion("2.64"):
+            policy_arg = {'policy': parsed_args.policy}
         server_group = compute_client.server_groups.create(
-            name=parsed_args.name,
-            policies=[parsed_args.policy])
+            name=parsed_args.name, **policy_arg)
+
         info.update(server_group._info)
 
         columns = _get_columns(info)
@@ -135,11 +141,15 @@ class ListServerGroup(command.Lister):
         compute_client = self.app.client_manager.compute
         data = compute_client.server_groups.list(parsed_args.all_projects)
 
+        policy_key = 'Policies'
+        if compute_client.api_version >= api_versions.APIVersion("2.64"):
+            policy_key = 'Policy'
+
         if parsed_args.long:
             column_headers = columns = (
                 'ID',
                 'Name',
-                'Policies',
+                policy_key,
                 'Members',
                 'Project Id',
                 'User Id',
@@ -148,7 +158,7 @@ class ListServerGroup(command.Lister):
             column_headers = columns = (
                 'ID',
                 'Name',
-                'Policies',
+                policy_key,
             )
 
         return (column_headers,
