@@ -16,15 +16,17 @@
 import copy
 import logging
 
+from cliff import columns as cliff_columns
+from osc_lib.cli import format_columns
 from osc_lib.cli import parseractions
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
+from osc_lib.utils import tags as _tag
 
 from openstackclient.i18n import _
 from openstackclient.identity import common as identity_common
 from openstackclient.network import sdk_utils
-from openstackclient.network.v2 import _tag
 
 
 LOG = logging.getLogger(__name__)
@@ -40,23 +42,27 @@ def _update_arguments(obj_list, parsed_args_list, option):
             raise exceptions.CommandError(msg)
 
 
-def _format_allocation_pools(data):
-    pool_formatted = ['%s-%s' % (pool.get('start', ''), pool.get('end', ''))
-                      for pool in data]
-    return ','.join(pool_formatted)
+class AllocationPoolsColumn(cliff_columns.FormattableColumn):
+    def human_readable(self):
+        pool_formatted = ['%s-%s' % (pool.get('start', ''),
+                                     pool.get('end', ''))
+                          for pool in self._value]
+        return ','.join(pool_formatted)
 
 
-def _format_host_routes(data):
-    # Map the host route keys to match --host-route option.
-    return utils.format_list_of_dicts(convert_entries_to_gateway(data))
+class HostRoutesColumn(cliff_columns.FormattableColumn):
+    def human_readable(self):
+        # Map the host route keys to match --host-route option.
+        return utils.format_list_of_dicts(
+            convert_entries_to_gateway(self._value))
 
 
 _formatters = {
-    'allocation_pools': _format_allocation_pools,
-    'dns_nameservers': utils.format_list,
-    'host_routes': _format_host_routes,
-    'service_types': utils.format_list,
-    'tags': utils.format_list,
+    'allocation_pools': AllocationPoolsColumn,
+    'dns_nameservers': format_columns.ListColumn,
+    'host_routes': HostRoutesColumn,
+    'service_types': format_columns.ListColumn,
+    'tags': format_columns.ListColumn,
 }
 
 
@@ -223,6 +229,10 @@ def _get_attrs(client_manager, parsed_args, is_create=True):
         attrs['enable_dhcp'] = True
     if parsed_args.no_dhcp:
         attrs['enable_dhcp'] = False
+    if parsed_args.dns_publish_fixed_ip:
+        attrs['dns_publish_fixed_ip'] = True
+    if parsed_args.no_dns_publish_fixed_ip:
+        attrs['dns_publish_fixed_ip'] = False
     if ('dns_nameservers' in parsed_args and
        parsed_args.dns_nameservers is not None):
         attrs['dns_nameservers'] = parsed_args.dns_nameservers
@@ -296,6 +306,17 @@ class CreateSubnet(command.ShowOne):
             action='store_true',
             help=_("Disable DHCP")
         )
+        dns_publish_fixed_ip_group = parser.add_mutually_exclusive_group()
+        dns_publish_fixed_ip_group.add_argument(
+            '--dns-publish-fixed-ip',
+            action='store_true',
+            help=_("Enable publishing fixed IPs in DNS")
+        )
+        dns_publish_fixed_ip_group.add_argument(
+            '--no-dns-publish-fixed-ip',
+            action='store_true',
+            help=_("Disable publishing fixed IPs in DNS (default)")
+        )
         parser.add_argument(
             '--gateway',
             metavar='<gateway>',
@@ -551,6 +572,17 @@ class SetSubnet(command.Command):
             action='store_true',
             help=_("Disable DHCP")
         )
+        dns_publish_fixed_ip_group = parser.add_mutually_exclusive_group()
+        dns_publish_fixed_ip_group.add_argument(
+            '--dns-publish-fixed-ip',
+            action='store_true',
+            help=_("Enable publishing fixed IPs in DNS")
+        )
+        dns_publish_fixed_ip_group.add_argument(
+            '--no-dns-publish-fixed-ip',
+            action='store_true',
+            help=_("Disable publishing fixed IPs in DNS")
+        )
         parser.add_argument(
             '--gateway',
             metavar='<gateway>',
