@@ -14,10 +14,9 @@
 
 import copy
 import random
+from unittest import mock
 import uuid
 
-import mock
-
 from osc_lib.cli import format_columns
 
 from openstackclient.tests.unit import fakes
